@@ -55,7 +55,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     if( !file.exists() )
       {
        QProcess *myProcess = new QProcess;
-       myProcess->execute("ln -s /etc/hildon/theme/mediaplayer/background.png /opt/qradio/background.png");
+       myProcess->execute("echo 'ln -s /etc/hildon/theme/mediaplayer/background.png /opt/qradio/background.png' | root");
       }
     file.close();
 
@@ -304,7 +304,7 @@ void MainWindow::manageStationsActionTriggered()
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                tr("<h2>QRadio 0.3.0</h2>"
+                tr("<h2>QRadio 0.3.3</h2>"
                    "<p>"
                    "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 
